#[non_exhaustive]pub struct EntityConfiguration {
pub entity_id: String,
pub entity_type: EntityType,
}Expand description
Provides the configuration information for users or groups in your IAM Identity Center identity source to grant access your Amazon Kendra experience.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entity_id: StringThe identifier of a user or group in your IAM Identity Center identity source. For example, a user ID could be an email.
entity_type: EntityTypeSpecifies whether you are configuring a User or a Group.
Implementations
Sourceimpl EntityConfiguration
impl EntityConfiguration
Sourcepub fn entity_id(&self) -> &str
pub fn entity_id(&self) -> &str
The identifier of a user or group in your IAM Identity Center identity source. For example, a user ID could be an email.
Sourcepub fn entity_type(&self) -> &EntityType
pub fn entity_type(&self) -> &EntityType
Specifies whether you are configuring a User or a Group.
Sourceimpl EntityConfiguration
impl EntityConfiguration
Sourcepub fn builder() -> EntityConfigurationBuilder
pub fn builder() -> EntityConfigurationBuilder
Creates a new builder-style object to manufacture EntityConfiguration.