#[non_exhaustive]pub struct EntityPersonaConfiguration {
pub entity_id: String,
pub persona: Persona,
}Expand description
Provides the configuration information for users or groups in your IAM Identity Center identity source for access to your Amazon Kendra experience. Specific permissions are defined for each user or group once they are granted access to your Amazon Kendra experience.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entity_id: StringThe identifier of a user or group in your IAM Identity Center identity source. For example, a user ID could be an email.
persona: PersonaThe persona that defines the specific permissions of the user or group in your IAM Identity Center identity source. The available personas or access roles are Owner and Viewer. For more information on these personas, see Providing access to your search page.
Implementations
Sourceimpl EntityPersonaConfiguration
impl EntityPersonaConfiguration
Sourcepub fn entity_id(&self) -> &str
pub fn entity_id(&self) -> &str
The identifier of a user or group in your IAM Identity Center identity source. For example, a user ID could be an email.
Sourcepub fn persona(&self) -> &Persona
pub fn persona(&self) -> &Persona
The persona that defines the specific permissions of the user or group in your IAM Identity Center identity source. The available personas or access roles are Owner and Viewer. For more information on these personas, see Providing access to your search page.
Sourceimpl EntityPersonaConfiguration
impl EntityPersonaConfiguration
Sourcepub fn builder() -> EntityPersonaConfigurationBuilder
pub fn builder() -> EntityPersonaConfigurationBuilder
Creates a new builder-style object to manufacture EntityPersonaConfiguration.