#[non_exhaustive]pub struct FeaturedDocument {
pub id: Option<String>,
}Expand description
A featured document. This document is displayed at the top of the search results page, placed above all other results for certain queries. If there's an exact match of a query, then the document is featured in the search results.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The identifier of the document to feature in the search results. You can use the Query API to search for specific documents with their document IDs included in the result items, or you can use the console.
Implementations
Sourceimpl FeaturedDocument
impl FeaturedDocument
Sourcepub fn builder() -> FeaturedDocumentBuilder
pub fn builder() -> FeaturedDocumentBuilder
Creates a new builder-style object to manufacture FeaturedDocument.