#[non_exhaustive]pub struct FeaturedDocumentWithMetadata {
pub id: Option<String>,
pub title: Option<String>,
pub uri: Option<String>,
}Expand description
A featured document with its metadata information. This document is displayed at the top of the search results page, placed above all other results for certain queries. If there's an exact match of a query, then the document is featured in the search results.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The identifier of the featured document with its metadata. You can use the Query API to search for specific documents with their document IDs included in the result items, or you can use the console.
title: Option<String>The main title of the featured document.
uri: Option<String>The source URI location of the featured document.
Implementations
Sourceimpl FeaturedDocumentWithMetadata
impl FeaturedDocumentWithMetadata
Sourceimpl FeaturedDocumentWithMetadata
impl FeaturedDocumentWithMetadata
Sourcepub fn builder() -> FeaturedDocumentWithMetadataBuilder
pub fn builder() -> FeaturedDocumentWithMetadataBuilder
Creates a new builder-style object to manufacture FeaturedDocumentWithMetadata.